/*
 * urltester.Main:  retrieve output from a URL.
 *
# Copyright (c) 2011, Perforce Software, Inc.  All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1.  Redistributions of source code must retain the above copyright
#     notice, this list of conditions and the following disclaimer.
#
# 2.  Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL PERFORCE SOFTWARE, INC. BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
 */

package urltester;

import java.io.InputStream;
import java.net.URL;

/**
 *
 * @author jbrown
 */
public class Main {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) throws Exception {

        if (args.length < 1 ) {
            System.out.println("Format:");
            System.out.println("  java -jar urltester.jar <url>\n") ;
            System.out.println("Sample JIRA url:  https://JIRA-HOST:PORT/rpc/soap/jirasoapservice-v2");
            System.exit(1);
        }
        String url = args[0] ;
        System.out.println("Connecting to " + url + ":");
        URL dest = new URL(url);
        InputStream in = null ;
        byte[] buf = new byte[4096];
        int bytesRetrieved = 0 ;
        try {
            in = dest.openStream();
            while (true) {
                int r = in.read(buf);
                if (r < 0) {
                    break;
                }
                System.out.write(buf, 0, r);
                bytesRetrieved += r ;
            }
        } finally {
            if ( in != null ) {
                try {
                    in.close();
                } catch(Throwable t) {
                    // should never be here
                    t.printStackTrace();
                }
            }
        }
        System.out.println("\nBytes retrieved: " + bytesRetrieved );
    }
}
